@@ -38,6 +38,7 @@ import inspect
 import socket
 import errno
 import time
+import re
 
 log = logging.getLogger(__name__)
 
@@ -1064,6 +1065,9 @@ class Client(object):
         # Expand paths if necessary (/foo/{bar,baz} --> ['/foo/bar', '/foo/baz'])
         paths = glob.expand_paths(paths)
 
+        # Replace multiple directory separators with a single one ('/foo//bar///baz' -> '/foo/bar/baz')
+        paths = [re.sub('/+', '/', path) for path in paths]
+
         for path in paths:
             if not path.startswith("/"):
                 path = self._join_user_path(path)
@@ -1080,7 +1084,10 @@ class Client(object):
                     raise FileNotFoundException("`%s': No such file or directory" % path)
                 elif not fileinfo and check_nonexistence:
                     yield processor(path, None)
-                    return
+                    continue
+                elif fileinfo and check_nonexistence:
+                    yield {"path": path, "result": False, "error": "File already exists"}
+                    continue
 
                 if (include_toplevel and fileinfo) or not self._is_dir(fileinfo.fs):
                     # Construct the full path before processing
@@ -1204,7 +1211,6 @@ class Client(object):
     def _get_file_info(self, path):
         request = client_proto.GetFileInfoRequestProto()
         request.src = path
-
         return self.service.getFileInfo(request)
 
     def _join_user_path(self, path):
